package sms;

import java.util.*;

import zyneo.sms.Sms;

/**
* Copyright (c) 2002 Zyneo
*
* $Id: SmsAccount.java,v 1.1 2003/03/23 15:44:26 nian Exp $
*
* @author nian
* 
* <pre>
* $Log: SmsAccount.java,v $
* Revision 1.1  2003/03/23 15:44:26  nian
* Added file
*
* 
* </pre>
*/

/**
*
* Represents one Sms-account used for
* sending and receiving messages.
*
*/
public class SmsAccount
{
	/** The office our account is bound to */
	protected SmsOffice m_office;
	
	/** The user which owns this account */
	protected String m_user;
	
	/** All our sent messages */
	protected LinkedList m_sent_messages;
	
	/** All our received messages */
	protected LinkedList m_received_messages;
	
	/**
	 * Constructor for SmsAccount
	 * 
	 * @param ss The SmsOffice which administrates this account.
	 * @param user The username bound to this account
	 */
	protected SmsAccount(SmsOffice ss,String user)
	{
		m_office = ss;
		m_user = user;
		
		m_sent_messages = new LinkedList();
		m_received_messages = new LinkedList();

	}

	/**
	*
	* Sends an SMS-message
	*
	* @param to The Sms-Message to send
	* @param message The Message itself
	* @param reports Indicates if status reports is requested
	* @param valid The validity time
	*
	* @throws Exception if something failes
	*/
	public void send(String to,String message,boolean reports,java.util.Date valid)
		throws Exception
	{
		// Lets construct a SmsBean
		SmsBean sms = new SmsBean(to,message,reports,valid);

		// Let the Office deliver this message
		m_office.send(this,sms);
		
		// Add to our sent messages
		m_sent_messages.addLast(sms);
	}

	/**
	*
	* Retrives a list containing SmsBean:s
	* representing all messages sent using this
	* account.
	*
	* @return A list with all message sent
	*/
	public List getSent()
	{
		return m_sent_messages;
	}
	

	/**
	*
	* Retrives a list containing zyneo.sms.Sms representing 
	* all messages received.
	*
	* @return A list with all receied messages
	*/
	public List getReceived()
	{
		return m_received_messages;
	}
	
	/**
	*
	* Used by the SmsOffice to put incoming
	* messages to this account
	*
	* @param sms The Sms received
	*
	*/
	protected void incoming(Sms sms)
	{
		m_received_messages.add(sms);
	}	
	/**
	 * Returns the user.
	 * @return String
	 */
	public String getUser()
	{
		return m_user;
	}

}
